@@ -858,23 +858,24 @@ int main( int argc, char *argv[] ) {
 	/* Read GConf Info */
 	gconf_client = gconf_client_get_default ();
 	uic->transformPlus = gconf_client_get_bool(gconf_client, GCONF_TRANSFORM_PLUS_KEY, NULL);
-	g_object_unref (gconf_client);
 
 	hildon_window_set_menu (appview, create_menus (uic));
 
 /* Gnokii : read the config */
 	gn_error err;
 #ifdef GNOKII_GCONF
-	gnokiiCfg = getGnokiiCfg(NULL);
-	gnokiiFile = TRUE;
-	state = g_new0(struct gn_statemachine,1);
-	if ((err = gn_cfg_memory_read ((char **)gnokiiCfg)) != GN_ERR_NONE) {
-		hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("Error reading gnokii configuration %s\n%s\n%s\n%s\n%s"), gn_error_print(err), gnokiiCfg[0], gnokiiCfg[1], gnokiiCfg[2], gnokiiCfg[3]);
-		gnokiiFile = FALSE;
-	} else if ((err = gn_cfg_phone_load(NULL, state)) != GN_ERR_NONE) {
-		fprintf(stderr, "%s\n", gn_error_print(err));
-		hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("gn_cfg_phone_load %s"), gn_error_print(err));
-		gnokiiFile = FALSE;
+	if (!isGnokiiRcFileUsed(gconf_client, NULL)) {
+		gnokiiCfg = getGnokiiCfg(gconf_client, NULL);
+		gnokiiFile = TRUE;
+		state = g_new0(struct gn_statemachine,1);
+		if ((err = gn_cfg_memory_read ((char **)gnokiiCfg)) != GN_ERR_NONE) {
+			hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("Error reading gnokii configuration %s\n%s\n%s\n%s\n%s"), gn_error_print(err), gnokiiCfg[0], gnokiiCfg[1], gnokiiCfg[2], gnokiiCfg[3]);
+			gnokiiFile = FALSE;
+		} else if ((err = gn_cfg_phone_load(NULL, state)) != GN_ERR_NONE) {
+			fprintf(stderr, "%s\n", gn_error_print(err));
+			hildon_banner_show_informationf(GTK_WIDGET(appview), GTK_STOCK_DIALOG_ERROR, _("gn_cfg_phone_load %s"), gn_error_print(err));
+			gnokiiFile = FALSE;
+		}
 	}
 #endif
 	if (!gnokiiFile) {
@@ -884,6 +885,7 @@ int main( int argc, char *argv[] ) {
 		}
 	}
 
+	g_object_unref (gconf_client);
 	
 	g_print("avant osso init\n");
 
